@@ -1,13 +1,16 @@
+# frozen_string_literal: true
+
 module Gitlab
   # Wrapper for the Gitlab REST API.
   class Client < API
-    Dir[File.expand_path('../client/*.rb', __FILE__)].each { |f| require f }
+    Dir[File.expand_path('client/*.rb', __dir__)].each { |f| require f }
 
     # Please keep in alphabetical order
     include AccessRequests
     include AwardEmojis
     include Boards
     include Branches
+    include BroadcastMessages
     include BuildVariables
     include Builds
     include Commits
@@ -28,33 +31,35 @@ module Gitlab
     include PipelineSchedules
     include PipelineTriggers
     include Pipelines
+    include ProjectBadges
     include Projects
+    include ProtectedTags
     include Repositories
     include RepositoryFiles
+    include RepositorySubmodules
     include Runners
     include Services
     include Sidekiq
     include Snippets
     include SystemHooks
     include Tags
+    include Templates
     include Todos
     include Users
+    include Versions
+    include Wikis
 
     # Text representation of the client, masking private token.
     #
     # @return [String]
     def inspect
       inspected = super
-
-      if @private_token
-        inspected = inspected.sub! @private_token, only_show_last_four_chars(@private_token)
-      end
-
+      inspected.sub! @private_token, only_show_last_four_chars(@private_token) if @private_token
       inspected
     end
 
-    def url_encode(s)
-      URI.encode(s.to_s, /\W/)
+    def url_encode(url)
+      URI.encode(url.to_s, /\W/)
     end
 
     private
