@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class Gitlab::Client
   # Defines methods related to merge requests.
   # @see https://docs.gitlab.com/ce/api/merge_requests.html
@@ -25,7 +27,7 @@ class Gitlab::Client
     # @option options [Integer] :page The page number.
     # @option options [Integer] :per_page The number of results per page.
     # @return [Array<Gitlab::ObjectifiedHash>]
-    def merge_requests(project, options={})
+    def merge_requests(project, options = {})
       get("/projects/#{url_encode project}/merge_requests", query: options)
     end
 
@@ -41,6 +43,18 @@ class Gitlab::Client
       get("/projects/#{url_encode project}/merge_requests/#{id}")
     end
 
+    # Gets a list of merge request pipelines.
+    #
+    # @example
+    #   Gitlab.merge_request_pipelines(5, 36)
+    #
+    # @param  [Integer, String] project The ID or name of a project.
+    # @param  [Integer] id The ID of a merge request.
+    # @return [Array<Gitlab::ObjectifiedHash>]
+    def merge_request_pipelines(project, id)
+      get("/projects/#{url_encode project}/merge_requests/#{id}/pipelines")
+    end
+
     # Creates a merge request.
     #
     # @example
@@ -58,7 +72,7 @@ class Gitlab::Client
     # @option options [Integer] :target_project_id (optional) The target project ID.
     # @option options [String] :labels (optional) Labels as a comma-separated list.
     # @return [Gitlab::ObjectifiedHash] Information about created merge request.
-    def create_merge_request(project, title, options={})
+    def create_merge_request(project, title, options = {})
       body = { title: title }.merge(options)
       post("/projects/#{url_encode project}/merge_requests", body: body)
     end
@@ -77,7 +91,7 @@ class Gitlab::Client
     # @option options [Integer] :assignee_id The ID of a user to assign merge request.
     # @option options [String] :state_event New state (close|reopen|merge).
     # @return [Gitlab::ObjectifiedHash] Information about updated merge request.
-    def update_merge_request(project, id, options={})
+    def update_merge_request(project, id, options = {})
       put("/projects/#{url_encode project}/merge_requests/#{id}", body: options)
     end
 
@@ -91,7 +105,7 @@ class Gitlab::Client
     # @param  [Hash] options A customizable set of options.
     # @option options [String] :merge_commit_message Custom merge commit message
     # @return [Gitlab::ObjectifiedHash] Information about updated merge request.
-    def accept_merge_request(project, id, options={})
+    def accept_merge_request(project, id, options = {})
       put("/projects/#{url_encode project}/merge_requests/#{id}/merge", body: options)
     end
 
@@ -205,7 +219,7 @@ class Gitlab::Client
     #     * :x (Integer) X coordinate (for 'image' diff notes)
     #     * :y (Integer) Y coordinate (for 'image' diff notes)
     # @return [Gitlab::ObjectifiedHash] The created merge request discussion.
-    def create_merge_request_discussion(project, merge_request_id, options={})
+    def create_merge_request_discussion(project, merge_request_id, options = {})
       post("/projects/#{url_encode project}/merge_requests/#{merge_request_id}/discussions", body: options)
     end
 
@@ -271,5 +285,30 @@ class Gitlab::Client
     def delete_merge_request_discussion_note(project, merge_request_id, discussion_id, note_id)
       delete("/projects/#{url_encode project}/merge_requests/#{merge_request_id}/discussions/#{discussion_id}/notes/#{note_id}")
     end
+
+    # Gets a list of merge request diff versions
+    #
+    # @example
+    #   Gitlab.merge_request_versions(5, 1)
+    #   Gitlab.merge_request_versions('gitlab', 1)
+    # @param  [Integer, String] project The ID or name of a project.
+    # @param  [Integer] id The ID of a merge request.
+    # @return [Gitlab::ObjectifiedHash] A list of the merge request versions.
+    def merge_request_diff_versions(project, merge_request_id)
+      get("/projects/#{url_encode project}/merge_requests/#{merge_request_id}/versions")
+    end
+
+    # Gets the diff a single merge request diff version\
+    #
+    # @example
+    #   Gitlab.merge_request_diff_version(5, 1, 1)
+    #   Gitlab.merge_request_diff_version('gitlab', 1, 1)
+    # @param  [Integer, String] project The ID or name of a project.
+    # @param  [Integer] id The ID of a merge request.
+    # @param  [Integer] id The ID of a merge request diff version.
+    # @return [Gitlab::ObjectifiedHash] Record of the specific diff
+    def merge_request_diff_version(project, merge_request_id, version_id)
+      get("/projects/#{url_encode project}/merge_requests/#{merge_request_id}/versions/#{version_id}")
+    end
   end
 end
