@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class Gitlab::Client
   # Defines methods related to projects.
   # @see https://docs.gitlab.com/ce/api/projects.html
@@ -10,14 +12,11 @@ class Gitlab::Client
     # @param  [Hash] options A customizable set of options.
     # @option options [Integer] :page The page number.
     # @option options [Integer] :per_page The number of results per page.
-    # @option options [String] :scope Scope of projects. 'owned' for list of projects owned by the authenticated user, 'all' to get all projects (admin only)
+    # (Any provided options will be passed to Gitlab. See {https://docs.gitlab.com/ce/api/projects.html#list-all-projects Gitlab docs} for all valid options)
+    #
     # @return [Array<Gitlab::ObjectifiedHash>]
-    def projects(options={})
-      if options[:scope]
-        get("/projects/#{options[:scope]}", query: options)
-      else
-        get("/projects", query: options)
-      end
+    def projects(options = {})
+      get('/projects', query: options)
     end
 
     # Search for projects by name.
@@ -33,10 +32,10 @@ class Gitlab::Client
     # @option options [String] :order_by Return requests ordered by id, name, created_at or last_activity_at fields
     # @option options [String] :sort Return requests sorted in asc or desc order
     # @return [Array<Gitlab::ObjectifiedHash>]
-    def project_search(query, options={})
-      get("/projects", query: options.merge(search:query))
+    def project_search(query, options = {})
+      get('/projects', query: options.merge(search: query))
     end
-    alias_method :search_projects, :project_search
+    alias search_projects project_search
 
     # Gets information about a project.
     #
@@ -50,21 +49,6 @@ class Gitlab::Client
       get("/projects/#{url_encode id}")
     end
 
-    # Gets a list of project events.
-    #
-    # @example
-    #   Gitlab.project_events(42)
-    #   Gitlab.project_events('gitlab')
-    #
-    # @param  [Integer, String] project The ID or path of a project.
-    # @param  [Hash] options A customizable set of options.
-    # @option options [Integer] :page The page number.
-    # @option options [Integer] :per_page The number of results per page.
-    # @return [Array<Gitlab::ObjectifiedHash>]
-    def project_events(project, options={})
-      get("/projects/#{url_encode project}/events", query: options)
-    end
-
     # Creates a new project.
     #
     # @example
@@ -86,8 +70,8 @@ class Gitlab::Client
     # @option options [Boolean] :public The setting for making a project public (0 = false, 1 = true).
     # @option options [Integer] :user_id The user/owner id of a project.
     # @return [Gitlab::ObjectifiedHash] Information about created project.
-    def create_project(name, options={})
-      url = options[:user_id] ? "/projects/user/#{options[:user_id]}" : "/projects"
+    def create_project(name, options = {})
+      url = options[:user_id] ? "/projects/user/#{options[:user_id]}" : '/projects'
       post(url, body: { name: name }.merge(options))
     end
 
@@ -114,7 +98,7 @@ class Gitlab::Client
     # @option options [Integer] :page The page number.
     # @option options [Integer] :per_page The number of results per page.
     # @return [Array<Gitlab::ObjectifiedHash>]
-    def team_members(project, options={})
+    def team_members(project, options = {})
       get("/projects/#{url_encode project}/members", query: options)
     end
 
@@ -134,28 +118,34 @@ class Gitlab::Client
     #
     # @example
     #   Gitlab.add_team_member('gitlab', 2, 40)
+    #   Gitlab.add_team_member('gitlab', 2, 40, { expires_at: "2018-12-31"})
     #
     # @param  [Integer, String] project The ID or path of a project.
     # @param  [Integer] id The ID of a user.
     # @param  [Integer] access_level The access level to project.
     # @param  [Hash] options A customizable set of options.
+    # @option options [String] :expires_at A date string in the format YEAR-MONTH-DAY.
     # @return [Gitlab::ObjectifiedHash] Information about added team member.
-    def add_team_member(project, id, access_level)
-      post("/projects/#{url_encode project}/members", body: { user_id: id, access_level: access_level })
+    def add_team_member(project, id, access_level, options = {})
+      body = { user_id: id, access_level: access_level }.merge(options)
+      post("/projects/#{url_encode project}/members", body: body)
     end
 
     # Updates a team member's project access level.
     #
     # @example
     #   Gitlab.edit_team_member('gitlab', 3, 20)
+    #   Gitlab.edit_team_member('gitlab', 3, 20, { expires_at: "2018-12-31"})
     #
     # @param  [Integer, String] project The ID or path of a project.
     # @param  [Integer] id The ID of a user.
     # @param  [Integer] access_level The access level to project.
     # @param  [Hash] options A customizable set of options.
+    # @option options [String] :expires_at A date string in the format YEAR-MONTH-DAY.
     # @return [Array<Gitlab::ObjectifiedHash>] Information about updated team member.
-    def edit_team_member(project, id, access_level)
-      put("/projects/#{url_encode project}/members/#{id}", body: { access_level: access_level })
+    def edit_team_member(project, id, access_level, options = {})
+      body = { access_level: access_level }.merge(options)
+      put("/projects/#{url_encode project}/members/#{id}", body: body)
     end
 
     # Removes a user from project team.
@@ -182,7 +172,7 @@ class Gitlab::Client
     # @option options [Integer] :page The page number.
     # @option options [Integer] :per_page The number of results per page.
     # @return [Array<Gitlab::ObjectifiedHash>]
-    def project_hooks(project, options={})
+    def project_hooks(project, options = {})
       get("/projects/#{url_encode project}/hooks", query: options)
     end
 
@@ -212,7 +202,7 @@ class Gitlab::Client
     # @param  option [Boolean] :merge_requests_events Trigger hook on merge_requests events (0 = false, 1 = true)
     # @param  option [Boolean] :tag_push_events Trigger hook on push_tag events (0 = false, 1 = true)
     # @return [Gitlab::ObjectifiedHash] Information about added hook.
-    def add_project_hook(project, url, options={})
+    def add_project_hook(project, url, options = {})
       body = { url: url }.merge(options)
       post("/projects/#{url_encode project}/hooks", body: body)
     end
@@ -231,7 +221,7 @@ class Gitlab::Client
     # @param  option [Boolean] :merge_requests_events Trigger hook on merge_requests events (0 = false, 1 = true)
     # @param  option [Boolean] :tag_push_events Trigger hook on push_tag events (0 = false, 1 = true)
     # @return [Gitlab::ObjectifiedHash] Information about updated hook.
-    def edit_project_hook(project, id, url, options={})
+    def edit_project_hook(project, id, url, options = {})
       body = { url: url }.merge(options)
       put("/projects/#{url_encode project}/hooks/#{id}", body: body)
     end
@@ -271,7 +261,7 @@ class Gitlab::Client
     # @param  option [Boolean] :deny_delete_tag Do not allow users to remove git tags with git push (0 = false, 1 = true)
     # @param  option [String] :commit_message_regex Commit message regex
     # @return [Gitlab::ObjectifiedHash] Information about added push rule.
-    def add_push_rule(id, options={})
+    def add_push_rule(id, options = {})
       post("/projects/#{url_encode id}/push_rule", body: options)
     end
 
@@ -286,7 +276,7 @@ class Gitlab::Client
     # @param  option [Boolean] :deny_delete_tag Do not allow users to remove git tags with git push (0 = false, 1 = true)
     # @param  option [String] :commit_message_regex Commit message regex
     # @return [Gitlab::ObjectifiedHash] Information about updated push rule.
-    def edit_push_rule(id, options={})
+    def edit_push_rule(id, options = {})
       put("/projects/#{url_encode id}/push_rule", body: options)
     end
 
@@ -298,7 +288,7 @@ class Gitlab::Client
     #
     # @param  [Integer] id The ID of a project.
     # @return [Gitlab::ObjectifiedHash] Information about deleted push rule.
-    def delete_push_rule(id, options={})
+    def delete_push_rule(id)
       delete("/projects/#{url_encode id}/push_rule")
     end
 
@@ -336,7 +326,7 @@ class Gitlab::Client
     # @option options [Integer] :page The page number.
     # @option options [Integer] :per_page The number of results per page.
     # @return [Array<Gitlab::ObjectifiedHash>]
-    def deploy_keys(project, options={})
+    def deploy_keys(project, options = {})
       get("/projects/#{url_encode project}/deploy_keys", query: options)
     end
 
@@ -355,14 +345,15 @@ class Gitlab::Client
     # Creates a new deploy key.
     #
     # @example
-    #   Gitlab.create_deploy_key(42, 'My Key', 'Key contents')
+    #   Gitlab.create_deploy_key(42, 'My Key', 'Key contents', can_push: true)
     #
     # @param  [Integer, String] project The ID or path of a project.
     # @param  [String] title The title of a deploy key.
     # @param  [String] key The content of a deploy key.
+    # @param  [Hash] options A customizable set of options.
     # @return [Gitlab::ObjectifiedHash] Information about created deploy key.
-    def create_deploy_key(project, title, key)
-      post("/projects/#{url_encode project}/deploy_keys", body: { title: title, key: key })
+    def create_deploy_key(project, title, key, options = {})
+      post("/projects/#{url_encode project}/deploy_keys", body: { title: title, key: key }.merge(options))
     end
 
     # Enables a deploy key at the project.
@@ -411,10 +402,28 @@ class Gitlab::Client
     # @param  [Hash] options A customizable set of options.
     # @option options [String] :sudo The username the project will be forked for
     # @return [Gitlab::ObjectifiedHash] Information about the forked project.
-    def create_fork(id, options={})
+    def create_fork(id, options = {})
       post("/projects/#{url_encode id}/fork", body: options)
     end
 
+    # Get a list of all visible projects across GitLab for the authenticated user.
+    # When accessed without authentication, only public projects are returned.
+    #
+    # Note: This feature was introduced in GitLab 10.1
+    #
+    # @example
+    #   Gitlab.project_forks(42)
+    #
+    # @param  [Hash] options A customizable set of options.
+    # @option options [Integer] :page The page number.
+    # @option options [Integer] :per_page The number of results per page.
+    # @option options [String] :order_by Return requests ordered by id, name, created_at or last_activity_at fields
+    # @option options [String] :sort Return requests sorted in asc or desc order
+    # @return [Array<Gitlab::ObjectifiedHash>]
+    def project_forks(id, options = {})
+      get("/projects/#{url_encode id}/forks", query: options)
+    end
+
     # Updates an existing project.
     #
     # @example
@@ -430,7 +439,7 @@ class Gitlab::Client
     # (Any provided options will be passed to Gitlab. See {https://docs.gitlab.com/ce/api/projects.html#edit-project Gitlab docs} for all valid options)
     #
     # @return [Gitlab::ObjectifiedHash] Information about the edited project.
-    def edit_project(id, options={})
+    def edit_project(id, options = {})
       put("/projects/#{url_encode id}", body: options)
     end
 
@@ -446,6 +455,30 @@ class Gitlab::Client
       post("/projects/#{url_encode project}/share", body: { group_id: id, group_access: group_access })
     end
 
+    # Unshare project with group.
+    #
+    # @example
+    #   Gitlab.unshare_project_with_group('gitlab', 2)
+    #
+    # @param  [Integer, String] project The ID or path of a project.
+    # @param  [Integer] id The ID of a group.
+    # @return [void] This API call returns an empty response body.
+    def unshare_project_with_group(project, id)
+      delete("/projects/#{url_encode project}/share/#{id}")
+    end
+
+    # Transfer a project to a new namespace.
+    #
+    # @example
+    #   Gitlab.transfer_project(42, 'yolo')
+    #
+    # @param  [Integer, String] project The ID or path of a project
+    # @param  [Integer, String] namespace The ID or path of the namespace to transfer to project to
+    # @return [Gitlab::ObjectifiedHash] Information about transfered project.
+    def transfer_project(project, namespace)
+      put("/projects/#{url_encode project}/transfer", body: { namespace: namespace })
+    end
+
     # Stars a project.
     # @see https://docs.gitlab.com/ce/api/projects.html#star-a-project
     #
@@ -471,5 +504,71 @@ class Gitlab::Client
     def unstar_project(id)
       delete("/projects/#{url_encode id}/star")
     end
+
+    # Get a list of visible projects for the given user.
+    # @see https://docs.gitlab.com/ee/api/projects.html#list-user-projects
+    #
+    # @example
+    #   Gitlab.user_projects(1)
+    #   Gitlab.user_projects(1, { order_by: 'last_activity_at' })
+    #   Gitlab.user_projects('username', { order_by: 'name', sort: 'asc' })
+    #
+    # @param  [Integer, String] user_id The ID or username of the user.
+    # @param  [Hash] options A customizable set of options.
+    # @option options [String] :per_page Number of projects to return per page
+    # @option options [String] :page The page to retrieve
+    # @option options [String] :order_by Return projects ordered by id, name, path, created_at, updated_at, or last_activity_at fields.
+    # @option options [String] :sort Return projects sorted in asc or desc order.
+    # @return [Array<Gitlab::ObjectifiedHash>]
+    def user_projects(user_id, options = {})
+      get("/users/#{url_encode user_id}/projects", query: options)
+    end
+
+    # Uploads a file to the specified project to be used in an issue or
+    # merge request description, or a comment.
+    # @see https://docs.gitlab.com/ee/api/projects.html#upload-a-file
+    #
+    # @example
+    #   Gitlab.upload_file(1, File.open(File::NULL, 'r'))
+    #   File.open('myfile') { |file| Gitlab.upload_file(1, file) }
+    #
+    # @param  [Integer, String] id The ID or path of a project.
+    # @param  [File] The file you are interested to upload.
+    # @return [Gitlab::ObjectifiedHash]
+    def upload_file(id, file)
+      post("/projects/#{url_encode id}/uploads", body: { file: file })
+    end
+
+    # Get all project templates of a particular type
+    # @see https://docs.gitlab.com/ce/api/project_templates.html
+    #
+    # @example
+    #   Gitlab.project_templates(1, 'dockerfiles')
+    #   Gitlab.project_templates(1, 'licenses')
+    #
+    # @param  [Integer, String] id The ID or URL-encoded path of the project.
+    # @param  [String] type The type (dockerfiles|gitignores|gitlab_ci_ymls|licenses) of the template
+    # @return [Array<Gitlab::ObjectifiedHash>]
+    def project_templates(project, type)
+      get("/projects/#{url_encode project}/templates/#{type}")
+    end
+
+    # Get one project template of a particular type
+    # @see https://docs.gitlab.com/ce/api/project_templates.html
+    #
+    # @example
+    #   Gitlab.project_template(1, 'dockerfiles', 'dockey')
+    #   Gitlab.project_template(1, 'licenses', 'gpl', { project: 'some project', fullname: 'Holder Holding' })
+    #
+    # @param  [Integer, String] project The ID or URL-encoded path of the project.
+    # @param  [String] type The type (dockerfiles|gitignores|gitlab_ci_ymls|licenses) of the template
+    # @param  [String] key The key of the template, as obtained from the collection endpoint
+    # @param  [Hash] options A customizable set of options.
+    # @option options [String] project(optional) The project name to use when expanding placeholders in the template. Only affects licenses
+    # @option options [String] fullname(optional) The full name of the copyright holder to use when expanding placeholders in the template. Only affects licenses
+    # @return [Gitlab::ObjectifiedHash]
+    def project_template(project, type, key, options = {})
+      get("/projects/#{url_encode project}/templates/#{type}/#{key}", query: options)
+    end
   end
 end
