@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Gitlab
   module Error
     # Custom error class for rescuing from all Gitlab errors.
@@ -11,7 +13,7 @@ module Gitlab
 
     # Custom error class for rescuing from HTTP response errors.
     class ResponseError < Error
-      POSSIBLE_MESSAGE_KEYS = %i(message error_description error)
+      POSSIBLE_MESSAGE_KEYS = %i[message error_description error].freeze
 
       def initialize(response)
         @response = response
@@ -57,7 +59,7 @@ module Gitlab
         case message
         when Gitlab::ObjectifiedHash
           message.to_h.sort.map do |key, val|
-            "'#{key}' #{(val.is_a?(Hash) ? val.sort.map { |k, v| "(#{k}: #{v.join(' ')})" } : val).join(' ')}"
+            "'#{key}' #{(val.is_a?(Hash) ? val.sort.map { |k, v| "(#{k}: #{v.join(' ')})" } : [val].flatten).join(' ')}"
           end.join(', ')
         when Array
           message.join(' ')
