@@ -1,13 +1,14 @@
+# frozen_string_literal: true
+
 module Gitlab
   # Converts hashes to the objects.
   class ObjectifiedHash
     # Creates a new ObjectifiedHash object.
     def initialize(hash)
       @hash = hash
-      @data = hash.inject({}) do |data, (key, value)|
+      @data = hash.each_with_object({}) do |(key, value), data|
         value = ObjectifiedHash.new(value) if value.is_a? Hash
         data[key.to_s] = value
-        data
       end
     end
 
@@ -15,7 +16,7 @@ module Gitlab
     def to_hash
       @hash
     end
-    alias_method :to_h, :to_hash
+    alias to_h to_hash
 
     # @return [String] Formatted string with the class name, object id and original hash.
     def inspect
@@ -24,7 +25,7 @@ module Gitlab
 
     # Delegate to ObjectifiedHash.
     def method_missing(key)
-      @data.key?(key.to_s) ? @data[key.to_s] : nil
+      @data.key?(key.to_s) ? @data[key.to_s] : super
     end
 
     def respond_to_missing?(method_name, include_private = false)
