@@ -1,12 +1,14 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe Gitlab::PaginatedResponse do
   before do
     array = [1, 2, 3, 4]
-    @paginated_response = Gitlab::PaginatedResponse.new array
+    @paginated_response = described_class.new array
   end
 
-  it "responds to *_page and has_*_page methods" do
+  it 'responds to *_page and has_*_page methods' do
     expect(@paginated_response).to respond_to :first_page
     expect(@paginated_response).to respond_to :last_page
     expect(@paginated_response).to respond_to :next_page
@@ -18,14 +20,14 @@ describe Gitlab::PaginatedResponse do
   end
 
   context '.parse_headers!' do
-    it "parses headers" do
-      @paginated_response.parse_headers!('Link' => "<http://example.com/api/v3/projects?page=1&per_page=5>; rel=\"first\", <http://example.com/api/v3/projects?page=20&per_page=5>; rel=\"last\"")
+    it 'parses headers' do
+      @paginated_response.parse_headers!('Link' => '<http://example.com/api/v3/projects?page=1&per_page=5>; rel="first", <http://example.com/api/v3/projects?page=20&per_page=5>; rel="last"')
       client = @paginated_response.client = double('client')
       first_page_response = double('first_page_response')
       last_page_response = double('last_page_response')
-      allow(client).to receive(:endpoint).and_return("http://example.com/api/v3")
-      allow(client).to receive(:get).with("/projects?page=1&per_page=5").and_return(first_page_response)
-      allow(client).to receive(:get).with("/projects?page=20&per_page=5").and_return(last_page_response)
+      allow(client).to receive(:endpoint).and_return('http://example.com/api/v3')
+      allow(client).to receive(:get).with('/projects?page=1&per_page=5').and_return(first_page_response)
+      allow(client).to receive(:get).with('/projects?page=20&per_page=5').and_return(last_page_response)
       expect(@paginated_response.has_first_page?).to be true
       expect(@paginated_response.has_last_page?).to be true
       expect(@paginated_response.has_next_page?).to be false
@@ -38,7 +40,7 @@ describe Gitlab::PaginatedResponse do
   end
 
   context '.each_page' do
-    it "iterates pages" do
+    it 'iterates pages' do
       next_page = double('next_page')
       allow(@paginated_response).to receive(:has_next_page?).and_return(true)
       allow(@paginated_response).to receive(:next_page).and_return(next_page)
@@ -48,7 +50,7 @@ describe Gitlab::PaginatedResponse do
   end
 
   context '.auto_paginate' do
-    it "returns an array if block is not given" do
+    it 'returns an array if block is not given' do
       next_page = double('next_page')
       allow(@paginated_response).to receive(:has_next_page?).and_return(true)
       allow(@paginated_response).to receive(:next_page).and_return(next_page)
